==> cvtease-0.1.8.tar.gz: cvtease-0.1.8/README.md <==
# cvtease
## ⭐ Support This Project

If you like this project and want to support it, please consider giving it a star! 💖

[![Star on GitHub](https://img.shields.io/github/stars/w3cdpass/cvtease)](https://github.com/w3cdpass/cvtease)

![Downloads](https://img.shields.io/pypi/dm/cvtease)



### Follow the link to read the .md file.
<a href="https://github.com/w3cdpass/cvtease/blob/main/MD/decent_facial_landmark_detection.md">
    The link
</a>

****
[![PyPI version](https://img.shields.io/badge/pip%20install-cvtease-blue)](https://pypi.org/project/cvtease/)
![Python Version](https://img.shields.io/pypi/pyversions/cvtease)
![PyPI Version](https://img.shields.io/pypi/v/cvtease)
<!-- ![Build Status](https://img.shields.io/github/workflow/status/w3cdpass/cvtease/CI) -->
<!-- ![License](https://img.shields.io/pypi/l/cvtease) -->

CVTease is a CLI tool for computer vision that is currently under development. It includes functionalities such as face detection, facial keypoints detection, and a space shooter game using ASCII art.

## Features

- **Face Detection**: Open the camera and detect faces with visual feedback.
- **Facial Keypoints**: Detect and display key points on the face.
- **Space Shooter Game**: Play a lightweight ASCII-based space shooter game.
- **GUI Interface**: A simple GUI for managing face detection and keypoints.

## pypi.org

```bash
# You can install CVTease directly from PyPI using pip:
pip install cvtease


# clone the repository and use pip to install from source: 
git clone https://github.com/w3cdpass/cvtease.git
cd cvtease
pip install -e .

==> cvtease-0.1.15.tar.gz: cvtease-0.1.15/README.md <==
# cvtease
## ⭐ Support This Project

If you like this project and want to support it, please consider giving it a star! 💖

[![Star on GitHub](https://img.shields.io/github/stars/w3cdpass/cvtease)](https://github.com/w3cdpass/cvtease)  ![Downloads](https://img.shields.io/pypi/dm/cvtease)



### Follow the link to read the .md file.
<a href="https://github.com/w3cdpass/cvtease/blob/main/MD/decent_facial_landmark_detection.md">
    The link
</a>

****
######  ➡️INSTALL DEPENDENCIES ON YOUR LOCAL MACHINE⬅️
[![MediaPipe](https://img.shields.io/badge/MediaPipe-blue?logo=mediapipe)](https://mediapipe.dev/)
[![PySide6](https://img.shields.io/badge/PySide6-darkgreen?logo=qt)](https://pyside.org/)

****
[![PyPI version](https://img.shields.io/badge/pip%20install-cvtease-blue)](https://pypi.org/project/cvtease/)
![Python Version](https://img.shields.io/pypi/pyversions/cvtease)
![PyPI Version](https://img.shields.io/pypi/v/cvtease)
<!-- ![Build Status](https://img.shields.io/github/workflow/status/w3cdpass/cvtease/CI) -->
<!-- ![License](https://img.shields.io/pypi/l/cvtease) -->

CVTease is a CLI tool for computer vision that is currently under development. It includes functionalities such as face detection, facial keypoints detection, and a space shooter game using ASCII art.

## Features

- **Face Detection**: Open the camera and detect faces with visual feedback.
- **Facial Keypoints**: Detect and display key points on the face.
- **Space Shooter Game**: Play a lightweight ASCII-based space shooter game.
- **GUI Interface**: A simple GUI for managing face detection and keypoints.

## Installation
### Linux
```bash


# If Python and pip are not installed, install them using your package manager:
sudo apt update
sudo apt install python3 python3-pip -y
pip3 install cvtease
```

***
```bash
# Install CVTease directly from PyPI using pip:
pip install cvtease
```
***
# Or clone the repository and use pip to install from source:
```bash
git clone https://github.com/w3cdpass/cvtease.git
cd cvtease
python -m venv venv
# linux/macos source venv/bin/activate
venv\scripts\activate
pip install -r requirement.txt
pip install -e .
